<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fil_PH">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX Network Assistant</source>
        <translation>Katuwang para sa MX Network</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>About...</source>
        <translation>Patungkol sa...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="108"/>
        <source>Help</source>
        <translation>Tulong</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <source>&amp;Close</source>
        <translation>&amp;Isara</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="231"/>
        <source>Status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>IP address</source>
        <translation>Address ng IP </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>Hardware detected</source>
        <translation>Nakadetect ng Hardware </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Enable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <location filename="../mainwindow.ui" line="603"/>
        <location filename="../mainwindow.ui" line="712"/>
        <source>Re-scan</source>
        <translation>I-scan muli</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="383"/>
        <source>Enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>Interface</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="393"/>
        <source>Driver</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Description</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>Vendor</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>Product</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Disable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Active interface</source>
        <translation>Aktibong interface</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="446"/>
        <source>WiFi status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>Unblocks all soft/hard blocked wireless devices</source>
        <translation>Tatanggalan ng sagabal ang lahat ng soft/hard sa  wireless devices</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="471"/>
        <source>Unblock WiFi Devices</source>
        <translation>Tanggalin sa pagkakatrangka ang mga device ng WiFi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="502"/>
        <source>Linux drivers</source>
        <translation>Mga drivers ng Linux </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="514"/>
        <source>Associated Linux drivers</source>
        <translation>Mga nakaugnay sa drivers ng Linux </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Load Driver</source>
        <translation>Ikarga ang Driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="586"/>
        <source>Unload Driver</source>
        <translation>I-unload ang Driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="622"/>
        <location filename="../mainwindow.cpp" line="833"/>
        <source>Block Driver</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="640"/>
        <source>Windows drivers</source>
        <translation>Windows drivers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="646"/>
        <source>Available Windows drivers</source>
        <translation>Matatagpuang  drivers ng Windows</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>Remove Driver</source>
        <translation>Magtanggal ng Driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="690"/>
        <source>Add Driver</source>
        <translation>Magdagdag ng Driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="729"/>
        <source>About NDISwrapper</source>
        <translation>Patungkol sa NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="741"/>
        <source>Install NDISwrapper</source>
        <translation>I-install ang NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="751"/>
        <source>In order to use Windows drivers you need first to install NDISwrapper</source>
        <translation>Kailangan munang mai-install ang  NDISwrapper bago magamit ang mga Windows drivers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="767"/>
        <source>Uninstall NDISwrapper</source>
        <translation>I-uninstall ang NDISwrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="798"/>
        <source>Net diagnostics</source>
        <translation>Pagsusuri ng Net </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="810"/>
        <source>Ping</source>
        <translation>Ping</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="816"/>
        <location filename="../mainwindow.ui" line="933"/>
        <source>Target URL:</source>
        <translation>Ang URL na pinupuntirya:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="826"/>
        <source>Packets</source>
        <translation>Mga Packets</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="871"/>
        <location filename="../mainwindow.ui" line="991"/>
        <source>Start</source>
        <translation>Magsimula</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="887"/>
        <location filename="../mainwindow.ui" line="1007"/>
        <source>Clear</source>
        <translation>Linisin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="900"/>
        <location filename="../mainwindow.ui" line="1020"/>
        <source>Cancel</source>
        <translation>Huwag ituloy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="927"/>
        <source>Traceroute</source>
        <translation>Traceroute</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="943"/>
        <source>Hops</source>
        <translation>Hops</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="86"/>
        <source>IP address from router:</source>
        <translation>address ng IP mula sa router:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>External IP address:</source>
        <translation>External na IP address:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>Interface: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <location filename="../mainwindow.cpp" line="138"/>
        <source>Driver: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>Description: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="140"/>
        <source>Product: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="141"/>
        <source>Vendor: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="127"/>
        <location filename="../mainwindow.cpp" line="142"/>
        <source>Enabled: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="195"/>
        <location filename="../mainwindow.cpp" line="209"/>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopyahin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <location filename="../mainwindow.cpp" line="211"/>
        <location filename="../mainwindow.cpp" line="225"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <location filename="../mainwindow.cpp" line="212"/>
        <location filename="../mainwindow.cpp" line="226"/>
        <source>Copy &amp;All</source>
        <translation>Kopyahin &amp;Lahat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <location filename="../mainwindow.cpp" line="214"/>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Traceroute not installed</source>
        <translation>Ang Traceroute  ay hindi naka-install</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Traceroute is not installed, do you want to install it now?</source>
        <translation>Ang Traceroute ay hindi naka-install, Gusto mo ba siyang i-install ngayon?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Traceroute hasn&apos;t been installed</source>
        <translation>Ang Traceroute ay hindi nai-install</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
        <translation>Ang Traceroute ay di maaring mai-install. Maaring gumagamit ka ng LiveCD o di ka maaring  makapasok sa  software repository,</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
        <translation>Ang Traceroute ay hindi naka-install at walang koneksyon ng Internet na maaring matagpuan kaya hindi maaring mai-install</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>No destination host</source>
        <translation>Walang destination host</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Please fill in the destination host field</source>
        <translation>Punan ang dako ng destination host</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <source>Loaded Drivers</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>Unloaded Drivers</source>
        <translation>Mga drivers na hindi na-iunload</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>Blocked Drivers</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>Blocked Broadcom Drivers</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>Ndiswrapper is not installed</source>
        <translation>Ang Ndiswrapper ay hindi nai-install</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>driver installed</source>
        <translation>ang driver ay naka-install</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source> and in use by </source>
        <translation> ay kasalukuyang ginagamit ng </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>. Alternate driver: </source>
        <translation>. driver na kahalili: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="609"/>
        <source>Module blocked</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <source>Installation successful</source>
        <translation>Matagumpay ang pagkaka-install</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="765"/>
        <source>Error detected, could not compile ndiswrapper driver.</source>
        <translation>Nakasalunga ng Error, di maaring maipon ang  driver ng ndiswrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="768"/>
        <source>Error detected, could not install ndiswrapper.</source>
        <translation>Nakatagpo ng Error kaya di maaring mai-install ang ndiswrapper.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="780"/>
        <source>Error encountered while removing Ndiswrapper</source>
        <translation>Nakatagpo ng Error habang tinatanggal ang Ndiswrapper</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>Unblock Driver</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="862"/>
        <source>enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="865"/>
        <source>disabled</source>
        <translation>naka-disable</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="868"/>
        <source>WiFi hardware switch is off</source>
        <translation>Ang switch WiFi hardware ay nakapatay.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="875"/>
        <source>Locate the Windows driver you want to add</source>
        <translation>Hanapin ang Windows driver na gusto mong idagdag</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="876"/>
        <source>Windows installation information file (*.inf)</source>
        <translation>Impormasyon sa pag-iinstall ng file ng windows (*.inf)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="907"/>
        <source>*.sys file not found</source>
        <translation>ang file *.sys ay di matagpuan</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
        <translation>Ang file na *.sys ay dapat nakalulan sa kaparehong lugar ng file na  *.inf  %1 </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="919"/>
        <source>sys file reference not found</source>
        <translation>ang file ng sys ay hindi matagpuan</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="920"/>
        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
        <translation>Ang file na sys na inihahain ay di maaring matukoy matapos ng parsing ng file ng inf</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="937"/>
        <source>Ndiswrapper driver removed.</source>
        <translation>Ang driver ng Ndiswrapper ay natanggal na.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>%1 Help</source>
        <translation>%1 Tulong</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="957"/>
        <source>Could not unlock devices.
WiFi device(s) might already be unlocked.</source>
        <translation>Di maaring matanggal sa pagkakatrangka ang mga device.
Ang mga device ang WiFi ay maaring natanggal na sa pagkakatrangka.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="959"/>
        <source>WiFi devices unlocked.</source>
        <translation>Natanggal na sa pagkakatrangka ang mga device ng WiFi.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="974"/>
        <source>About %1</source>
        <translation>Patungkol sa %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="975"/>
        <source>Version: </source>
        <translation>Bersyon: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="976"/>
        <source>Program for troubleshooting and configuring network for MX Linux</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="978"/>
        <source>Copyright (c) MEPIS LLC and MX Linux</source>
        <translation>Mga Karapatan (c) MEPIS LLC at MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="979"/>
        <source>%1 License</source>
        <translation>%1 Pahintulot</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1005"/>
        <source>Driver loaded successfully</source>
        <translation>Maayos na nai-karga ang Driver</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1020"/>
        <source>Driver unloaded successfully</source>
        <translation>Ang drive driver mayos na nai-unload</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Lisensya</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>Ulat na mga pagbabago</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Huwag ituloy</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>&amp;Isara</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <location filename="../main.cpp" line="78"/>
        <source>Error</source>
        <translation>May error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>You must run this program with admin access.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Could not load </source>
        <translation>Hindi maaring mai-load </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="649"/>
        <source>Could not unload </source>
        <translation>Hindi maaring mai-unload </translation>
    </message>
</context>
</TS>